summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/tms36xx.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/tms36xx.cpp')
-rw-r--r--src/devices/sound/tms36xx.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/devices/sound/tms36xx.cpp b/src/devices/sound/tms36xx.cpp
index 89211700a7d..73ec59b4121 100644
--- a/src/devices/sound/tms36xx.cpp
+++ b/src/devices/sound/tms36xx.cpp
@@ -355,7 +355,7 @@ void tms36xx_device::device_start()
{
int enable = 0;
- m_channel = stream_alloc(0, 1, clock() * 64);
+ m_channel = stream_alloc_legacy(0, 1, clock() * 64);
m_samplerate = clock() * 64;
m_basefreq = clock();
@@ -394,10 +394,10 @@ void tms36xx_device::device_start()
//-------------------------------------------------
// sound_stream_update - handle a stream update
//-------------------------------------------------
-void tms36xx_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void tms36xx_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
int samplerate = m_samplerate;
stream_sample_t *buffer = outputs[0];
@@ -394,10 +394,10 @@ void tms36xx_device::device_start()
//-------------------------------------------------
-// sound_stream_update - handle a stream update
+// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------